==> jbpm-distro-4.0.jar: jbpm-4.0/src/org/jbpm/pvm/internal/jobexecutor/JobExecutorMessageSession.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.jobexecutor;

import org.jbpm.api.job.Message;
import org.jbpm.internal.log.Log;
import org.jbpm.pvm.internal.env.Environment;
import org.jbpm.pvm.internal.env.Transaction;
import org.jbpm.pvm.internal.session.DbSession;
import org.jbpm.pvm.internal.session.MessageSession;
import org.jbpm.pvm.internal.util.ReflectUtil;

/**
 * @author Tom Baeyens
 */
public class JobExecutorMessageSession implements MessageSession {
  
  private static final Log log = Log.getLog(JobExecutorMessageSession.class.getName());
  
  /* injected */
  DbSession dbSession;

  /* injected */
  Transaction transaction;
  
  boolean isNotificationAdded;

  public void send(Message message) {
    log.debug("sending message "+ReflectUtil.getUnqualifiedClassName(message.getClass()));

    dbSession.save(message);

    if (!isNotificationAdded) {
      isNotificationAdded = true;
      
      JobExecutor jobExecutor = Environment.getCurrent().get(JobExecutor.class);
      if (jobExecutor!=null) {
        // notify the job executor after the transaction is completed
        log.trace("registering job executor notifier with "+transaction);
        transaction.registerSynchronization(new JobAddedNotification(jobExecutor));
      }
    }
  }
}

==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/pvm/internal/jobexecutor/JobExecutorMessageSession.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.jobexecutor;

import org.jbpm.api.job.Message;
import org.jbpm.internal.log.Log;
import org.jbpm.pvm.internal.env.EnvironmentImpl;
import org.jbpm.pvm.internal.env.Transaction;
import org.jbpm.pvm.internal.session.DbSession;
import org.jbpm.pvm.internal.session.MessageSession;
import org.jbpm.pvm.internal.util.ReflectUtil;

/**
 * @author Tom Baeyens
 */
public class JobExecutorMessageSession implements MessageSession {
  
  private static final Log log = Log.getLog(JobExecutorMessageSession.class.getName());
  
  /* injected */
  DbSession dbSession;

  /* injected */
  Transaction transaction;
  
  boolean isNotificationAdded;

  public void send(Message message) {
    log.debug("sending message "+ReflectUtil.getUnqualifiedClassName(message.getClass()));

    dbSession.save(message);

    if (!isNotificationAdded) {
      isNotificationAdded = true;
      
      JobExecutor jobExecutor = EnvironmentImpl.getCurrent().get(JobExecutor.class);
      if (jobExecutor!=null) {
        // notify the job executor after the transaction is completed
        log.trace("registering job executor notifier with "+transaction);
        transaction.registerSynchronization(new JobAddedNotification(jobExecutor));
      }
    }
  }
}
